@@ -64,8 +64,8 @@ struct fxt_blockev {
 static int fxt_fill_blockev(fxt_t fxt, fxt_blockev_t evs)
 {
 	off_t offset=0;
-	int fd=evs->fxt->fd;
-	fxt_block_enter(fxt, fd, &evs->block);
+	FILE *fstream=evs->fxt->fstream;
+	fxt_fblock_enter(fxt, fstream, &evs->block);
 
 	switch (GET_BLOCK_TYPE(evs->block)) {
 	case FXT_BLOCK_TRACES_KERNEL_RAW32:
@@ -85,18 +85,18 @@ static int fxt_fill_blockev(fxt_t fxt, fxt_blockev_t evs)
 		return -1;
 	}
 
-
 	switch (evs->type) {
 	case FXT_TRACE_KERNEL_RAW32:
 	case FXT_TRACE_KERNEL_RAW64:
-		READ(64, offset);
+ 	        READ(64, offset);
 		/* Fall thru */
 	case FXT_TRACE_USER_RAW32:
 	case FXT_TRACE_USER_RAW64:
-		if ((evs->cur_pos=lseek(fd,offset,SEEK_CUR))<0) {
+		if ((fseek(fstream,offset,SEEK_CUR))<0) {
 			perror("seeking to start of events");
 			return -1;
 		}
+		evs->cur_pos=ftell(fstream);
 		break;
 	}
 	switch (evs->type) {
@@ -137,18 +137,19 @@ fxt_blockev_t fxt_blockev_enter(fxt_t fxt)
 int fxt_next_ev(fxt_blockev_t evs, int ev_type, struct fxt_ev *ev)
 {
 	fxt_t fxt = evs->fxt;
-	int fd = fxt->fd;
+	FILE *fstream = fxt->fstream;
 	int size_ev=0;
 	int i;
 	int ret=0;
 	struct fxt_ev_64 e;
 
-#define READEV_VAR(size, var) \
-   { READ(size, var); \
-     size_ev += size/8 ; \
-   }
+#define READEV_VAR(size, var)			\
+	{ READ(size, var);	\
+	  size_ev += size/8 ;			\
+	}
+
 #define READEV(size, field) \
-   READEV_VAR(size, e.field)
+	READEV_VAR(size, e.field)
 
 	switch (evs->type) {
 	case FXT_TRACE_KERNEL_RAW32:
@@ -166,7 +167,7 @@ int fxt_next_ev(fxt_blockev_t evs, int ev_type, struct fxt_ev *ev)
 			/* On repositionne cur_pos */
 			evs->cur_pos = evs->raw.start_data+fxt->infos.page_size;
 			evs->raw.start_data=evs->cur_pos;
-			if (lseek(fd,evs->cur_pos,SEEK_SET)!=evs->cur_pos) {
+			if (fseek(fstream,evs->cur_pos,SEEK_SET)!=0) {
 				fprintf(stderr, "Unable to go to next page at offset %"PRIu64"u\n", evs->cur_pos);
 				return 1;
 			}
@@ -175,11 +176,11 @@ int fxt_next_ev(fxt_blockev_t evs, int ev_type, struct fxt_ev *ev)
 			{
 				uint32_t u32;
 				int res;
-				res = read(fd, &u32, sizeof(u32));
+				res = fread(&u32, sizeof(u32), 1, fxt->fstream);
 				SWAP(32,u32);
 				if (res < 0)
 					return -1;
-				if (res < sizeof(u32) /* FIXME: pas forcment fin de fichier */
+				if (res < 1 /* FIXME: pas forcment fin de fichier */
 					|| u32 == FKT_EOF)
 					return FXT_EV_EOT;
 				if (!u32) {
@@ -206,55 +207,30 @@ int fxt_next_ev(fxt_blockev_t evs, int ev_type, struct fxt_ev *ev)
 	/* L'vnement est prsent, on peut le lire dans 'e' */
 	switch (evs->type) {
 	case FXT_TRACE_KERNEL_RAW32:
-	case FXT_TRACE_KERNEL_RAW64:
 		READEV(32,time);
-		break;
-	case FXT_TRACE_USER_RAW32:
-	case FXT_TRACE_USER_RAW64:
-		READEV(64,time);
-		break;
-	default:
-		NOT_MANAGED;
-	}
-
-	switch (evs->type) {
-	case FXT_TRACE_KERNEL_RAW32:
 		READEV(16, kernel.pid);
-		break;
-	case FXT_TRACE_USER_RAW32:
-		READEV(32, user.tid);
-		break;
-	case FXT_TRACE_USER_RAW64:
-		READEV(64, user.tid);
-		break;
-	default:
-		NOT_MANAGED;
-	}
-
-	switch (evs->type) {
-	case FXT_TRACE_KERNEL_RAW32:
 		READEV(16, cpu);
-		break;
-	case FXT_TRACE_USER_RAW32:
-	case FXT_TRACE_USER_RAW64:
-		break;
-	default:
-		NOT_MANAGED;
-	}
-
-	switch (evs->type) {
-	case FXT_TRACE_KERNEL_RAW32:
-	case FXT_TRACE_USER_RAW32:
 		READEV(32, code);
 		break;
+
 	case FXT_TRACE_KERNEL_RAW64:
+		READEV(32,time);
+		READEV(64, code);
+		break;
+	case FXT_TRACE_USER_RAW32:
+		READEV(64,time);
+		READEV(32, user.tid);
+		READEV(32, code);
+		break;
 	case FXT_TRACE_USER_RAW64:
+		READEV(64,time);
+		READEV(64, user.tid);
 		READEV(64, code);
 		break;
 	default:
 		NOT_MANAGED;
 	}
-	
+
 	/* calcul du nombre de paramtres */
 	switch (evs->type) {
 	case FXT_TRACE_KERNEL_RAW32:
@@ -451,8 +427,7 @@ int fxt_next_ev(fxt_blockev_t evs, int ev_type, struct fxt_ev *ev)
 }
 
 int fxt_rewind(fxt_blockev_t evs) {
-	if (evs->block.start != lseek(evs->fxt->fd,
-		    evs->block.start,SEEK_SET)) {
+	if (fseek(evs->fxt->fstream,evs->block.start,SEEK_SET)!=0) {
 		perror("seeking to start of events");
 		return -1;
 	}
