@@ -100,6 +100,12 @@ __BEGIN_TEMPLATE_ARGS__
 ,P1,P2,P3,P4,P5
 *(args++)=(unsigned long)(P1);*(args++)=(unsigned long)(P2);*(args++)=(unsigned long)(P3);*(args++)=(unsigned long)(P4);*(args++)=(unsigned long)(P5);
 __END_TEMPLATE_ARGS__
+__BEGIN_TEMPLATE_ARGS__
+6
+,P1,P2,P3,P4,P5,P6
+,P1,P2,P3,P4,P5,P6
+*(args++)=(unsigned long)(P1);*(args++)=(unsigned long)(P2);*(args++)=(unsigned long)(P3);*(args++)=(unsigned long)(P4);*(args++)=(unsigned long)(P5);*(args++)=(unsigned long)(P6);
+__END_TEMPLATE_ARGS__
 
 #define FUT_CODE(CODE, n) ((((unsigned long)(CODE))<<8) | ((n) + 1))
 #define FUT_SIZE(n) (sizeof(fxt_trace_user_raw_t)+(n)*sizeof(long))
