@@ -1,8 +1,15 @@
 #include "../config.h"
 
 #ifdef MARCEL
-#define MARCEL_INTERNAL_INCLUDE
-#include "marcel.h"
+#  define MARCEL_INTERNAL_INCLUDE
+#  include "marcel.h"
+#else
+#  ifdef USE_GETTID
+#    include <unistd.h>
+#    include <sys/syscall.h>	/* For SYS_xxx definitions */
+#  else
+#    include <pthread.h>
+#  endif
 #endif
 
 #ifdef HAVE_CLOCK_GETTIME
@@ -17,6 +24,8 @@
 #include "fxt.h"
 #include "fut.h"
 
+extern int record_tid_activated;
+
 #ifdef PROFILE_NEW_FORMAT
 
 /* pseudo fonction pour trouver o crire un vnement dans les buffers */
@@ -174,7 +183,7 @@ fut_header (unsigned long code, ... )
 static unsigned long trash_buffer[8];
 
 unsigned long* fut_getstampedbuffer(unsigned long code, 
-						      int size)
+				    int size)
 {
 	unsigned long *prev_slot, *next_slot;
 
@@ -196,12 +205,12 @@ unsigned long* fut_getstampedbuffer(unsigned long code,
 	unsigned long long tick;
 #ifdef HAVE_CLOCK_GETTIME
 	struct timespec tp;
-#ifdef CLOCK_MONOTONIC_RAW
+#  ifdef CLOCK_MONOTONIC_RAW
 	/* avoid NTP mess */
 	clock_gettime(CLOCK_MONOTONIC_RAW, &tp);
-#else
+#  else
 	clock_gettime(CLOCK_MONOTONIC, &tp);
-#endif
+#  endif
 	tick = 1000000000ULL*tp.tv_sec+ tp.tv_nsec;
 #else
 	TBX_GET_TICK(tick);
@@ -211,8 +220,15 @@ unsigned long* fut_getstampedbuffer(unsigned long code,
 #ifdef MA__FUT_RECORD_TID
 	rec->tid=(unsigned long)MARCEL_SELF;
 #else
-	/* XXX for now, the tid field is not filled */
-	rec->tid = 0;
+	if (record_tid_activated) {
+#  ifdef USE_GETTID
+		rec->tid = syscall(SYS_gettid);
+#  else
+		rec->tid = pthread_self();
+#  endif
+	} else {
+		rec->tid = 0;
+	}
 #endif
 	rec->code = code;
 	return (unsigned long*)(rec->args);
